<?php

namespace App\Console\Commands\Flow;

use App\Models\JuxingAdAccount;
use App\Models\JxStarLiveFlowOrderList;
use App\Support\Log;
use App\Support\RedisModel;
use Illuminate\Console\Command;
use kwaiSDK\JuXing;

class FlowStarLiveOrderSync extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'Flow:StarLiveOrderSync';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = '流量助推-星直播订单列表接口';

    protected $runDays   = 90;
    protected $limit     = 100;
    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {
        $this->info(date('H:i') . ' 开始执行');
        $this->start();
        $this->info(date('H:i') . ' 结束执行');

        return 0;
    }

    public function start()
    {
        $curTime = time();
        while (true) {
            if ((time() - $curTime) >= 60) break;

            $dataJson = RedisModel::rPop(JuxingAdAccount::JUXING_FLOW_STAR_LIVE_SYNC_ADVID_LIST);
            if (empty($dataJson)) {
                sleep(2);
                continue;
            }

            $data = json_decode($dataJson, true);
            if (!isset($data['advertiserId'], $data['timeRange'])) {
                # 输出错误日志
                Log::error('数据参数不合法', $data, 'Flow:StarLiveOrderSync');
                continue;
            }

            $this->getOrderData($data);
        }
    }

    public function getOrderData($data)
    {
        $advertiserId = $data['advertiserId'];
        $timeRange    = $data['timeRange'];

        $accessToken = JuxingAdAccount::getAccessToken($advertiserId);
        $juxing = new JuXing($accessToken);

        $param = [
            'advertiser_id' => $advertiserId,
            'create_start_time'  => $timeRange['st'],
            'create_end_time'    => $timeRange['en'],
            'supplement_order_type'  => 2, //星直播
        ];

        $listGenerator = $this->generator($juxing, $param);

        foreach ($listGenerator as $list) {
            foreach ($list as $datum) {
                $this->allotmentData($advertiserId, $datum);
            }
        }
    }

    public function generator($juxing, $param)
    {
        $failRecord = [];
        $pageNumber = 1;
        $totalPage  = 1;
        do {
            $param['page_num']  = $pageNumber;
            $param['page_size'] = $this->limit;
            $rst = $juxing->supplementOrderV2()->liveList($param);

            if (isset($rst['code']) && ($rst['code'] == 0)) {
                yield $rst['data']['details'];

                $totalPage  = ceil($rst['data']['total_count']/$this->limit);
                $pageNumber ++;
            } else {
                if (isset($failRecord[$pageNumber])) {
                    $failRecord[$pageNumber] ++;
                } else {
                    $failRecord[$pageNumber] = 0;
                }

                if ($failRecord[$pageNumber] > 5) {
                    $message = $rst['message'] ?? null;
                    Log::error('请求接口错误->'.$message, $param, 'Flow:StarLiveOrderSync');
                    break;
                }
            }

            // 控频
            sleep(1);
        } while($pageNumber <= $totalPage);
    }

    public function allotmentData($advertiserId, $datum)
    {
        # 插入订单入库队列
        $orderItem = [
            'advertiser_id' => $advertiserId,
            'data'          => $datum
        ];
        RedisModel::lPush(JxStarLiveFlowOrderList::JUXING_STAR_LIVE_FLOW_ORDER_INDB_LIST, json_encode($orderItem));
        # 输出记录日志
//        Log::info('入库订单数据入队列成功', $orderItem, 'Flow:StarLiveOrderSync');

        return 0;
    }
}
