<?php

namespace App\Console\Commands\Flow;

use App\Models\JxStarLiveFlowOrderList;
use App\Models\JxStarLiveOrderList;
use App\Services\RdsLockService;
use App\Support\Log;
use App\Support\RedisModel;
use Illuminate\Console\Command;

class FlowStarLiveOrderToDb extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'Flow:StarLiveOrderToDb';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = '流量助推-星直播订单数据入库';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {
        $this->info(date('H:i') . ' 开始执行');
        $this->start();
        $this->info(date('H:i') . ' 结束执行');

        return 0;
    }

    public function start()
    {
        $curTime = time();
        while (true) {
            if ((time() - $curTime) >= 60) break;

            $dataJson = RedisModel::rPop(JxStarLiveFlowOrderList::JUXING_STAR_LIVE_FLOW_ORDER_INDB_LIST);
            if (empty($dataJson)) {
                sleep(2);
                continue;
            }

            $data = json_decode($dataJson, true);
            if (!isset($data['advertiser_id'], $data['data'])) {
                # 输出错误日志
                Log::error('数据参数不合法', $data, 'Flow:StarLiveOrderToDb');
                continue;
            }

            $this->orderDataInDb($data);
        }
    }

    public function orderDataInDb($data)
    {
        $advertiserId = $data['advertiser_id'];
        $dataVal      = $data['data'];

        $orderId = $dataVal['order_id'] ?? null;
        $supplement_order_id = $dataVal['supplement_order_id'] ?? null;
        if (empty($orderId) || empty($supplement_order_id)) {
            # 输出错误日志
            Log::error('orderId 为空', $data, 'Flow:StarLiveOrderToDb');
            return false;
        }

        $taskId = $dataVal['task_id'];

        $lockKey = RdsLockService::getRdsLockKey([
            'flowStarLive', $advertiserId, $orderId, $supplement_order_id,
        ]);

        if (RdsLockService::addRdsLock($lockKey)) {
            $orderInfo = JxStarLiveFlowOrderList::query()
                ->where('advertiser_id', $advertiserId)
                ->where('task_id', $taskId)
                ->where('order_id', $orderId)
                ->where('supplement_order_id', $supplement_order_id)
                ->where('enable', 1)
                ->first();
            if (empty($orderInfo)) {
                $orderInfo = new JxStarLiveFlowOrderList([
                    'advertiser_id' => $advertiserId,
                    'task_id'       => $taskId,
                    'order_id'      => $orderId,
                    'supplement_order_id'  => $supplement_order_id,
                ]);
            } else {
                //更新逻辑，过滤异常数据
                if(
                    !isset($dataVal['consume_amount'], $dataVal['audience_num'], $dataVal['played3s_num'], $dataVal['fans_increase_num'], $dataVal['item_impression_num'], $dataVal['interactive_num'], $dataVal['conversion_impression_num'], $dataVal['conversion_action_num']) ||
                    $dataVal['consume_amount'] < $orderInfo->consume_amount ||
                    $dataVal['audience_num'] < $orderInfo->audience_num ||
                    $dataVal['played3s_num'] < $orderInfo->played3s_num ||
                    $dataVal['fans_increase_num'] < $orderInfo->fans_increase_num ||
                    $dataVal['item_impression_num'] < $orderInfo->item_impression_num ||
                    $dataVal['interactive_num'] < $orderInfo->interactive_num ||
                    $dataVal['conversion_impression_num'] < $orderInfo->conversion_impression_num ||
                    $dataVal['conversion_action_num'] < $orderInfo->conversion_action_num

                ){
                    RdsLockService::delRdsLock($lockKey);
                    Log::error('订单数据异常返回', $dataVal, 'Flow:StarLiveOrderToDb');
                    return false;
                }
            }

            $orderInfo->status      = $dataVal['status'] ?? null;
            $orderInfo->promotion_begin_time  = isset($dataVal['promotion_begin_time']) && !empty($dataVal['promotion_begin_time']) ? $dataVal['promotion_begin_time'] : null;
            $orderInfo->target_type   = $dataVal['target_type'] ?? null;
            $orderInfo->unit_type     = $dataVal['unit_type'] ?? null;
            $orderInfo->unit_price    = $dataVal['unit_price'] ?? null;
            $orderInfo->amount        = $dataVal['amount'] ?? null;
            $orderInfo->consume_amount   = $dataVal['consume_amount'] ?? null;
            $orderInfo->audience_num        = $dataVal['audience_num'] ?? null;
            $orderInfo->played3s_num        = $dataVal['played3s_num'] ?? null;
            $orderInfo->fans_increase_num        = $dataVal['fans_increase_num'] ?? null;
            $orderInfo->item_impression_num        = $dataVal['item_impression_num'] ?? null;
            $orderInfo->interactive_num        = $dataVal['interactive_num'] ?? null;
            $orderInfo->conversion_impression_num        = $dataVal['conversion_impression_num'] ?? null;
            $orderInfo->conversion_action_num        = $dataVal['conversion_action_num'] ?? null;
            $orderInfo->conversion_action_cost        = $dataVal['conversion_action_cost'] ?? null;
            $orderInfo->cash_amount      = $dataVal['cash_amount'] ?? null;
            $orderInfo->client_amount    = $dataVal['client_amount'] ?? null;
            $orderInfo->agency_amount    = $dataVal['agency_amount'] ?? null;
            $orderInfo->credit_consume_amount = $dataVal['credit_consume_amount'] ?? null;
            $orderInfo->closing_time     = isset($dataVal['closing_time']) && !empty($dataVal['closing_time']) ? $dataVal['closing_time'] : null;
            $orderInfo->supplement_order_id   = $dataVal['supplement_order_id'] ?? null;
            $orderInfo->campaign_id      = $dataVal['campaign_id'] ?? null;
            $orderInfo->account_id       = $dataVal['account_id'] ?? null;
            $orderInfo->unit_ids         = isset($dataVal['unit_ids']) && !empty($dataVal['unit_ids']) ? json_encode($dataVal['unit_ids']) : null;
            $orderInfo->v2_supplement_order   = $dataVal['v2_supplement_order'] ? 1 : 0;
            $orderInfo->supplement_order_sense_id  = $dataVal['supplement_order_sense_id'] ?? null;
            $orderInfo->reward_amount    = $dataVal['reward_amount'] ?? null;

            #查网红信息
            $info = JxStarLiveOrderList::select('star_name', 'kwai_id', 'user_id', 'live_start_time')
                ->where('advertiser_id', $advertiserId)
                ->where('task_id', $taskId)
                ->where('order_id', $orderId)
                ->where('enable', 1)
                ->first();

            if(!empty($info)){
                $orderInfo->star_name = $info->star_name;
                $orderInfo->kwai_id = $info->kwai_id;
                $orderInfo->user_id = $info->user_id;
                $orderInfo->live_start_time = $info->live_start_time;
            }

            $orderInfo->save();

            RdsLockService::delRdsLock($lockKey);
        }

//        Log::info('订单数据入库成功', ['orderId' => $orderId], 'Flow:StarLiveOrderToDb');

        return 0;
    }
}


