<?php

namespace App\Console\Commands\Qtask;

use App\Models\JxQtaskLiveOrderDaily;
use App\Models\JxQtaskLiveOrderList;
use App\Models\JxStarUsers;
use App\Support\Log;
use App\Support\RedisModel;
use Illuminate\Console\Command;

class LiveDailyOrderDataInDb extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'Qtask:LiveDailyOrderDataInDb';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = '快任务直播分天订单数据入库';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {
        $this->info(date('H:i') . ' 开始执行');
        $this->start();
        $this->info(date('H:i') . ' 结束执行');

        return 0;
    }

    public function start()
    {
        $curTime = time();
        while (true) {
            if ((time() - $curTime) >= 60) break;

            $dataJson = RedisModel::rPop(JxQtaskLiveOrderDaily::JUXING_QTASK_LIVE_ORDER_DAILY_INDB_LIST);
            if (empty($dataJson)) {
                sleep(2);
                continue;
            }

            $data = json_decode($dataJson, true);
            if (!isset($data['advertiser_id'], $data['task_id'], $data['data'])) {
                # 输出错误日志
                Log::error('数据参数不合法', $data, 'Qtask:LiveDailyOrderDataInDb');
                continue;
            }

            $this->orderDataInDb($data);
        }
    }

    public function orderDataInDb($data)
    {
        $advertiserId = $data['advertiser_id'];
        $taskId       = $data['task_id'];
        $dataVal      = $data['data'];

        foreach($dataVal as $v){
            $order_id = $v['order_id'];
            #获取达人信息
            $order = JxQtaskLiveOrderList::query()
                ->select('star_name', 'kwai_id', 'user_id')
                ->where('advertiser_id', $advertiserId)
                ->where('task_id', $taskId)
                ->where('order_id', $order_id)
                ->first();

            foreach ($v['daily_data'] as $val) {
                $idate = $val['data_time_str'];
                $item = $val['live_effect_data'];

                $con = [
                    'advertiser_id' => $advertiserId,
                    'task_id' => $taskId,
                    'order_id' => $order_id,
                    'idate'   => $idate
                ];

                $attr = [];
                $attr['cost'] = $item['cost'] ?? null;
                $attr['item_impression_cnt'] = $item['item_impression_cnt'] ?? null;
                $attr['item_click_cnt'] = $item['item_click_cnt'] ?? null;
                $attr['app_download'] = $item['app_download'] ?? null;
                $attr['conversion_num'] = $item['conversion_num'] ?? null;
                $attr['star_name'] = $order->star_name ?? null; 
                $attr['kwai_id'] = $order->kwai_id ?? null; 
                $attr['user_id'] = $order->user_id ?? null; 

                if(!$attr['cost'] && !$attr['conversion_num'] && !$attr['item_impression_cnt'] && !$attr['item_click_cnt']){
                    continue; //过滤空值
                }

                JxQtaskLiveOrderDaily::updateOrCreate($con, $attr);
            }
        }

        Log::info('快任务直播订单分日数据入库成功', ['taskId' => $taskId], 'Qtask:LiveDailyOrderDataInDb');

        return 0;
    }
}

