<?php

namespace App\Console\Commands\Qtask;

use App\Models\JuxingAdAccount;
use App\Models\JxQtaskVideoOrderDaily;
use App\Support\Log;
use App\Support\RedisModel;
use Illuminate\Console\Command;
use kwaiSDK\JuXing;

class VideoDailyOrderSync extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'Qtask:VideoDailyOrderSync';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = '快任务订单分天接口';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {
        $this->info(date('H:i') . ' 开始执行');
        $this->start();
        $this->info(date('H:i') . ' 结束执行');

        return 0;
    }

    public function start()
    {
        $curTime = time();
        while (true) {
            if ((time() - $curTime) >= 60) break;

            $dataJson = RedisModel::rPop(JxQtaskVideoOrderDaily::JUXING_QTASK_VIDEO_ORDER_DAILY_SYNC_ORDERID_LIST);
            if (empty($dataJson)) {
                sleep(2);
                continue;
            }

            $data = json_decode($dataJson, true);
            if (!isset($data['advertiser_id'], $data['task_id'], $data['order_id'])) {
                # 输出错误日志
                Log::error('队列数据参数不合法', $data, 'Qtask:VideoDailyOrderSync');
                continue;
            }

            if(count($data['order_id'])>200){
                $dataArr = $this->dateDivid($data);

                Log::info('超过200个订单，分隔', [
                    'dataArr' => $dataArr,
                ], 'Qtask:VideoDailyOrderSync');

                foreach($dataArr as $da){
                    $this->getOrderData($da);
                    sleep(1); //防止触发风控限制
                }
            } else {
                $this->getOrderData($data);
                sleep(1); //防止触发风控限制
            }
        }
    }

    private function dateDivid($data)
    {
        $tmp = $data;
        $n = ceil(count($data['order_id'])/200);
        $res = array();
        for($i=1; $i<=$n; $i++){
            $offset = ($i-1) * 200;
            $order_ids = array_slice($data['order_id'], $offset, 200);

            $tmp['order_id'] = $order_ids;
            $res[] = $tmp;
        }

        return $res;
    }

    public function getOrderData($data)
    {
        $advertiserId = $data['advertiser_id'];
        $taskId       = $data['task_id'];
        $orderIds     = $data['order_id'];
        $start        = $data['start'] ?? date('Y-m-d', strtotime('-3 day'));  //默认同步近三天
        $end          = $data['end'] ?? date('Y-m-d');

        $accessToken = JuxingAdAccount::getAccessToken($advertiserId);
        $juxing = new JuXing($accessToken);

        $param = [
            'advertiser_id' => $advertiserId,
            'mission_id'    => $taskId,
            'order_id'      => $orderIds,
            'start_time'    => $start,
            'end_time'      => $end
        ];

        $rst = $juxing->investData()->quickTaskOrderDaily($param);

        if (isset($rst['code']) && ($rst['code'] == 0)) {
            $list = $rst['data'];

            Log::info('同步分日数据成功', [
                'param' => $param
            ], 'Qtask:VideoDailyOrderSync');

        } else {
            RedisModel::lPush(JxQtaskVideoOrderDaily::JUXING_QTASK_VIDEO_ORDER_DAILY_SYNC_ORDERID_LIST, json_encode($data));

            Log::info('同步视频订单分日数据失败', [
                'param' => $param,
                'rst' => $rst,
            ], 'Qtask:VideoDailyOrderSync');
            return ;
        }

        $this->allotmentData($advertiserId, $taskId, $list);
    }

    public function allotmentData($advertiserId, $taskId, $list)
    {
        # 插入订单入库队列
        $orderItem = [
            'advertiser_id' => $advertiserId,
            'task_id'       => $taskId,
            'data'          => $list
        ];

        RedisModel::lPush(JxQtaskVideoOrderDaily::JUXING_QTASK_VIDEO_ORDER_DAILY_INDB_LIST, json_encode($orderItem));
        # 输出记录日志
//        Log::info('入库订单分日数据入队列成功', [$taskId], 'Qtask:VideoDailyOrderSync');

        return 0;
    }
}
