<?php

namespace App\Console\Commands\Qtask;

use App\Models\JuxingAdAccount;
use App\Models\JxQtaskVideoOrderList;
use App\Models\JxQtaskVideoTaskList;
use App\Support\Log;
use App\Support\RedisModel;
use Illuminate\Console\Command;
use kwaiSDK\JuXing;

class VideoOrderDataSync extends Command
{
    /**
     * The name and signature of the console command.
     *
     * @var string
     */
    protected $signature = 'Qtask:VideoOrderDataSync';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = '快任务订单列表接口';

    protected $runDays   = 90;
    protected $limit     = 100;
    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct()
    {
        parent::__construct();
    }

    /**
     * Execute the console command.
     *
     * @return int
     */
    public function handle()
    {
        $this->info(date('H:i') . ' 开始执行');
        $this->start();
        $this->info(date('H:i') . ' 结束执行');

        return 0;
    }

    public function start()
    {
        $curTime = time();
        while (true) {
            if ((time() - $curTime) >= 60) break;

            $dataJson = RedisModel::rPop(JxQtaskVideoTaskList::JUXING_QTASK_VIDEO_ORDER_SYNC_TASKID_LIST);
            if (empty($dataJson)) {
                sleep(2);
                continue;
            }

            $data = json_decode($dataJson, true);
            if (!isset($data['advertiser_id'], $data['task_id'])) {
                # 输出错误日志
                Log::error('数据参数不合法', $data, 'Qtask:VideoOrderDataSync');
                continue;
            }

            $this->getOrderData($data);
        }
    }

    public function getOrderData($data)
    {
        $advertiserId = $data['advertiser_id'];
        $taskId       = $data['task_id'];

        $accessToken = JuxingAdAccount::getAccessToken($advertiserId);
        $juxing = new JuXing($accessToken);

        $param = [
            'advertiser_id' => $advertiserId,
            'task_id'       => $taskId,
        ];
        $listGenerator = $this->generator($juxing, $param);

        foreach ($listGenerator as $list) {
            foreach ($list as $datum) {
                $this->allotmentData($advertiserId, $taskId, $datum);
            }
        }
    }

    public function generator($juxing, $param)
    {
        $failRecord = [];
        $pageNumber = 1;
        $totalPage  = 1;
        do {
            $param['page_num']  = $pageNumber;
            $param['page_size'] = $this->limit;
            $rst = $juxing->investData()->quickTaskOrderList($param);

            if (isset($rst['code']) && ($rst['code'] == 0)) {
                yield $rst['data']['order_detail_resp'];

                $totalPage  = ceil($rst['data']['total']/$this->limit);
                $pageNumber ++;
            } else {
                if (isset($failRecord[$pageNumber])) {
                    $failRecord[$pageNumber] ++;
                } else {
                    $failRecord[$pageNumber] = 0;
                }

                if ($failRecord[$pageNumber] > 5) {
                    Log::error('请求接口错误', $param, 'Qtask:VideoOrderDataSync');
                    break;
                }
            }

            // 控频
            sleep(1);
        } while($pageNumber <= $totalPage);
    }

    public function allotmentData($advertiserId, $taskId, $datum)
    {
        # 加上日志过滤规则
        $starReleaseTime = $datum['star_release_time']
            ? date('Y-m-d', strtotime($datum['star_release_time'])) : null;
        if (empty($starReleaseTime)) {
            Log::error('该订单没有发布时间', $datum, 'Qtask:VideoOrderDataSync');
            return false;
        }

        if ($starReleaseTime < date('Y-m-d', strtotime("-{$this->runDays} day"))) {
            return 0;
        }

        # 插入订单入库队列
        $orderItem = [
            'advertiser_id' => $advertiserId,
            'task_id'       => $taskId,
            'data'          => $datum
        ];
        RedisModel::lPush(JxQtaskVideoOrderList::JUXING_QTASK_VIDEO_ORDER_INDB_LIST, json_encode($orderItem));
        # 输出记录日志
//        Log::info('入库订单数据入队列成功', $orderItem, 'Qtask:VideoOrderDataSync');

        return 0;
    }
}
