<?php

namespace App\Http\Controllers\Api\Data;

use App\Http\Controllers\Controller;

use App\Services\Data\SearchConfigService;
use Illuminate\Http\Request;

class SearchConfigController extends Controller
{
    public function configCheck(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'type'    => 'required|string',
        ]);

        if($validator->fails()) {
            return self::returnValue($validator->errors(), 100);
        }

        $type   = $request->input('type');

        list($result, $code) = SearchConfigService::configCheck($type);
        return self::returnValue($result, $code);
    }


    public function configInfo(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'type'  => 'required|string',
            'gr_id' => 'required|integer',
        ]);

        if($validator->fails()) {
            return self::returnValue($validator->errors(), 100);
        }

        $type = $request->input('type');
        $grId = $request->input('gr_id');

        list($result, $code) = SearchConfigService::configInfo($type, $grId);
        return self::returnValue($result, $code);
    }

    public function groupList(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'type'  => 'required|string',
        ]);

        if($validator->fails()) {
            return self::returnValue($validator->errors(), 100);
        }

        $type = $request->input('type');

        $result = SearchConfigService::groupList($type);
        return self::returnValue($result);
    }

    public function groupAdd(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'type'    => 'required|string',
            'title'   => 'required|string',
            'columns' => 'required|array',
        ]);

        if($validator->fails()) {
            return self::returnValue($validator->errors(), 100);
        }

        $type    = $request->input('type');
        $title   = $request->input('title');
        $columns = $request->input('columns');

        list($result, $code) = SearchConfigService::groupAdd($type, $title, $columns);
        return self::returnValue($result, $code);
    }

    public function groupEdit(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'type'    => 'required|string',
            'gr_id'   => 'required|integer',
            'columns' => 'nullable|array',
            'title'   => 'nullable|string',
            'enable'  => 'nullable|integer'
        ]);

        if($validator->fails()) {
            return self::returnValue($validator->errors(), 100);
        }

        $type    = $request->input('type');
        $grId    = $request->input('gr_id');
        $columns = $request->input('columns');
        $title   = $request->input('title');
        $enable  = $request->input('enable');

        list($result, $code) = SearchConfigService::groupEdit($type, $grId, $columns, $title, $enable);
        return self::returnValue($result, $code);
    }

    public function groupApply(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'type'    => 'required|string',
            'gr_id'   => 'required|integer',
        ]);

        if($validator->fails()) {
            return self::returnValue($validator->errors(), 100);
        }

        $type    = $request->input('type');
        $grId    = $request->input('gr_id');

        list($result, $code) = SearchConfigService::groupApply($type, $grId);
        return self::returnValue($result, $code);
    }

    #-------不需要模板--------#

    public function configDetail(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'type'  => 'required|string',
        ]);

        if($validator->fails()) {
            return self::returnValue($validator->errors(), 100);
        }

        $type = $request->input('type');

        list($result, $code) = SearchConfigService::configDetail($type);
        return self::returnValue($result, $code);
    }

    public function confEdit(Request $request)
    {
        $validator = \Validator::make($request->all(),[
            'type'    => 'required|string',
            'columns' => 'nullable|array',
        ]);

        if($validator->fails()) {
            return self::returnValue($validator->errors(), 100);
        }

        $type    = $request->input('type');
        $columns = $request->input('columns');

        list($result, $code) = SearchConfigService::confEdit($type, $columns);
        return self::returnValue($result, $code);
    }
}
