<?php

namespace App\Http\Controllers;

use App\Support\Error;
use Illuminate\Foundation\Auth\Access\AuthorizesRequests;
use Illuminate\Foundation\Bus\DispatchesJobs;
use Illuminate\Foundation\Validation\ValidatesRequests;
use Illuminate\Routing\Controller as BaseController;

class Controller extends BaseController
{
    use AuthorizesRequests, DispatchesJobs, ValidatesRequests;

    public static function returnValue($data = [], $errorNo = 0, $msg = '') {
        return [
            "data" => $data,
            "code" => $errorNo . '',
            "msg" => empty($msg) ? Error::getError($errorNo) : $msg,
        ];
    }

    /**
     * 统一分页响应格式
     * @param $data
     * @param $total
     * @param $pageSize
     * @param int $page
     * @param null $extra
     * @return array
     */
    public static function returnPageValue($data, $total, $page, $pageSize, $extra = null, $errorNo = 0, $msg = '')
    {
        $pages = $pageSize > 0 ? ceil($total / $pageSize) : 0;
        $hasNext = $page<$pages ? true : false;

        $result = [
            'data' => $data,
            'pageInfo' => [
            	'page' => $page,
            	'hasNext' => $hasNext,
                'totalPageSize' => $pages,
                'pageSize' => $pageSize,
                'totalNum' => $total  
            ]
        ];

        if( $extra !== null && is_array($extra) ){
            $result['extra'] = $extra;
        }

        return self::returnValue($result, $errorNo, $msg);
    }
}
