<?php


namespace App\Services\Data;


use App\Models\JxCostDailyData;
use App\Models\JxQtaskLiveOrderList;
use App\Models\JxQtaskVideoFlowOrderList;
use App\Models\JxQtaskVideoOrderList;
use App\Models\JxStarLiveFlowOrderList;
use App\Models\JxStarLiveOrderList;
use App\Models\JxStarVideoFlowOrderList;
use App\Models\JxStarVideoOrderList;
use App\Models\Sys\SysCustomerAdver;
use Illuminate\Support\Facades\Auth;

class ProductService
{
    public static function dataSummary($custId, $stDate, $enDate)
    {
        $result = [
            'starVideoCost'  => 0,
            'starLiveCost'   => 0,
            'quickTaskCost'  => 0,
            'flowAssistCost' => 0
        ];

        $userInfo = Auth::user();
        $custIds = $userInfo->custIds;

        #获取广告主id
        $adverQuery = SysCustomerAdver::query();
        if (empty($custId)) {
            $adverQuery->whereIn('customer_id', $custIds);
        } else {
            if (!in_array($custId, $custIds)) return false;
            $adverQuery->where('customer_id', $custId);
        }
        $adverIds = $adverQuery->where('enable', 1)->pluck('advertiser_id')->all();
        if(empty($adverIds)) return $result;

        $costData = JxCostDailyData::query()
            ->selectRaw("SUM(star_video_cost) AS star_video_cost")
            ->selectRaw("SUM(star_live_cost) AS star_live_cost")
            ->selectRaw("SUM(qtask_video_cost) AS qtask_video_cost")
            ->selectRaw("SUM(qtask_live_cost) AS qtask_live_cost")
            ->selectRaw("SUM(flow_star_video_cost) AS flow_star_video_cost")
            ->selectRaw("SUM(flow_star_live_cost) AS flow_star_live_cost")
            ->selectRaw("SUM(flow_qtask_video_cost) AS flow_qtask_video_cost")
            ->whereIn('advertiser_id', $adverIds)
            ->whereBetween('day', [$stDate, $enDate])
            ->where('enable', 1)
            ->first();
        # 星视频
        $result['starVideoCost'] += $costData->star_video_cost;

        # 星直播
        $result['starLiveCost'] += $costData->star_live_cost;

        # 星任务
        $result['quickTaskCost'] += $costData->qtask_video_cost;
        $result['quickTaskCost'] += $costData->qtask_live_cost;

        # 流量助推
        $result['flowAssistCost'] += $costData->flow_star_video_cost;
        $result['flowAssistCost'] += $costData->flow_star_live_cost;
        $result['flowAssistCost'] += $costData->flow_qtask_video_cost;

        self::formatData($result);

        return $result;
    }

    public static function dataStatistical($custId, $prType, $stDate, $enDate)
    {
        $userInfo = Auth::user();
        $custIds = $userInfo->custIds;

        #获取广告主id
        $adverQuery = SysCustomerAdver::query();
        if (empty($custId)) {
            $adverQuery->whereIn('customer_id', $custIds);
        } else {
            if (!in_array($custId, $custIds)) return false;
            $adverQuery->where('customer_id', $custId);
        }
        $adverIds = $adverQuery->where('enable', 1)->pluck('advertiser_id')->all();

        $fun = 'getPro'.ucwords($prType).'Data';
        $res = self::$fun($adverIds, $stDate, $enDate);

        return $res;
    }

    protected static function getProStarVideoData($adverIds, $stDate, $enDate)
    {
        $formatData = [
            'real_amount'         => 0,
            'view'                => 0,
            'play'                => 0,
            'action'              => 0,
            'admire'              => 0,
            'comment'             => 0,
            'click'               => 0,
            'play_5s'             => 0,
            'play_end'            => 0,
            'item_impression_cnt' => 0,
            'item_click_cnt'      => 0,
            'user_cnt'            => 0,
            'click_rate'          => 0,
            'play_5s_rate'        => 0,
            'play_end_rate'       => 0,
            'item_click_rate'     => 0,
        ];

        $trend   = getDayArr($stDate, $enDate, $formatData);
        $summary = [
            'tal_real_amount'         => 0,
            'tal_view'                => 0,
            'tal_play'                => 0,
            'tal_action'              => 0,
            'tal_admire'              => 0,
            'tal_comment'             => 0,
            'tal_click'               => 0,
            'tal_play_5s'             => 0,
            'tal_play_end'            => 0,
            'tal_item_impression_cnt' => 0,
            'tal_item_click_cnt'      => 0,
            'tal_user_cnt'            => 0,
            'tal_ctr'                 => 0,
            'tal_cpm'                 => 0,
            'tal_cpc'                 => 0,
            'tal_item_click_rate'     => 0,
            'tal_cpa'                 => 0,
            'tal_play_5s_rate'        => 0,
            'tal_play_end_rate'       => 0
        ];
        $list = [];

        if (!empty($adverIds)) {
            $orderList = JxStarVideoOrderList::query()
                ->selectRaw("DATE_FORMAT(star_release_time, '%Y-%m-%d') AS day")
                ->selectRaw("SUM(real_amount) AS real_amount")
                ->selectRaw("SUM(view) AS view")
                ->selectRaw("SUM(play) AS play")
                ->selectRaw("SUM(action) AS action")
                ->selectRaw("SUM(admire) AS admire")
                ->selectRaw("SUM(comment) AS comment")
                ->selectRaw("SUM(click) AS click")
                ->selectRaw("SUM(play_5s) AS play_5s")
                ->selectRaw("SUM(play_end) AS play_end")
                ->selectRaw("SUM(item_impression_cnt) AS item_impression_cnt")
                ->selectRaw("SUM(item_click_cnt) AS item_click_cnt")
                ->selectRaw("SUM(user_cnt) AS user_cnt")
                ->whereIn('advertiser_id', $adverIds)
                ->whereBetween('star_release_time', [$stDate.' 00:00:00', $enDate.' 23:59:59'])
                ->groupBy('day')
                ->orderByDesc('day')
                ->get();

            if ($orderList->isNotEmpty()) {
                $orderListMap = $orderList->keyBy('day')->toArray();

                foreach ($trend as &$item) {
                    $dataVal = $orderListMap[$item['day']] ?? [];
                    if (empty($dataVal)) continue;

                    # 处理汇总
                    $summary['tal_real_amount']         += $dataVal['real_amount'];
                    $summary['tal_view']                += $dataVal['view'];
                    $summary['tal_play']                += $dataVal['play'];
                    $summary['tal_action']              += $dataVal['action'];
                    $summary['tal_admire']              += $dataVal['admire'];
                    $summary['tal_comment']             += $dataVal['comment'];
                    $summary['tal_click']               += $dataVal['click'];
                    $summary['tal_item_impression_cnt'] += $dataVal['item_impression_cnt'];
                    $summary['tal_item_click_cnt']      += $dataVal['item_click_cnt'];
                    $summary['tal_play_5s']             += $dataVal['play_5s'];
                    $summary['tal_play_end']            += $dataVal['play_end'];

                    # 处理列表
                    $list[] = [
                        'day'                 => $dataVal['day'],
                        'view'                => $dataVal['view'],
                        'play'                => $dataVal['play'],
                        'action'              => $dataVal['action'],
                        'admire'              => $dataVal['admire'],
                        'comment'             => $dataVal['comment'],
                        'click'               => $dataVal['click'],
                        'item_impression_cnt' => $dataVal['item_impression_cnt'],
                        'item_click_cnt'      => $dataVal['item_click_cnt'],
                        'play_5s'             => $dataVal['play_5s'],
                        'play_end'            => $dataVal['play_end'],
                        'real_amount'         => round($dataVal['real_amount'] / 1000, 4),
                        'ctr'                 => $dataVal['view'] > 0
                            ? round($dataVal['click'] / $dataVal['view'] * 100, 4) : 0,
                        'cpm'                 => $dataVal['play'] > 0
                            ? round($dataVal['real_amount'] / $dataVal['play'], 4) : 0,
                        'cpc'                 => $dataVal['click'] > 0
                            ? round(($dataVal['real_amount'] / $dataVal['click']) / 1000, 4) : 0,
                        'item_click_rate'     => $dataVal['item_impression_cnt'] > 0
                            ? round($dataVal['item_click_cnt'] / $dataVal['item_impression_cnt'] * 100, 4) : 0,
                        'cpa'                 => $dataVal['item_click_cnt'] > 0
                            ? round(($dataVal['real_amount'] / $dataVal['item_click_cnt']) / 1000, 4) : 0,
                        'play_5s_rate'        => $dataVal['view'] > 0
                            ? round($dataVal['play_5s'] / $dataVal['view'] * 100, 4) : 0,
                        'play_end_rate'       => $dataVal['view'] > 0
                            ? round($dataVal['play_end'] / $dataVal['view'] * 100, 4) : 0

                    ];

                    # 处理曲线
                    $dataVal['real_amount']         = round($dataVal['real_amount'] / 1000, 4);
                    $dataVal['click_rate']          = $dataVal['view'] > 0
                        ? round($dataVal['click'] / $dataVal['view'] * 100, 4) : 0;
                    $dataVal['play_5s_rate']        = $dataVal['view'] > 0
                        ? round($dataVal['play_5s'] / $dataVal['view'] * 100, 4) : 0;
                    $dataVal['play_end_rate']       = $dataVal['view'] > 0
                        ? round($dataVal['play_end'] / $dataVal['view'] * 100, 4) : 0;
                    $dataVal['item_click_rate']     = $dataVal['item_impression_cnt'] > 0
                        ? round($dataVal['item_click_cnt'] / $dataVal['item_impression_cnt'] * 100, 4) : 0;
                    $item = $dataVal;
                }

                $summary['tal_ctr']             = $summary['tal_view'] > 0
                    ? round($summary['tal_click'] / $summary['tal_view'] * 100, 4) : 0;
                $summary['tal_cpm']             = $summary['tal_play'] > 0
                    ? round($summary['tal_real_amount'] / $summary['tal_play'], 4) : 0;
                $summary['tal_cpc']             = $summary['tal_click'] > 0
                    ? round(($summary['tal_real_amount'] / $summary['tal_click']) / 1000, 4) : 0;
                $summary['tal_item_click_rate'] = $summary['tal_item_impression_cnt'] > 0
                    ? round($summary['tal_item_click_cnt'] / $summary['tal_item_impression_cnt'] * 100, 4) : 0;
                $summary['tal_cpa']             = $summary['tal_item_click_cnt'] > 0
                    ? round(($summary['tal_real_amount'] / $summary['tal_item_click_cnt']) / 1000, 4) : 0;
                $summary['tal_play_5s_rate']    = $summary['tal_view'] > 0
                    ? round($summary['tal_play_5s'] / $summary['tal_view'] * 100, 4) : 0;
                $summary['tal_play_end_rate']   = $summary['tal_view'] > 0
                    ? round($summary['tal_play_end'] / $summary['tal_view'] * 100, 4) : 0;
                $summary['tal_real_amount']     = round($summary['tal_real_amount'] / 1000, 4);
            }
        }

        self::sortData($list);
        return [
            'trend'   => $trend,
            'summary' => $summary,
            'list'    => $list
        ];
    }

    protected static function getProStarLiveData($adverIds, $stDate, $enDate)
    {
        $formatData = [
            'real_amount'      => 0,
            'play_cnt'         => 0,
            'play_uv'          => 0,
            'like_cnt'         => 0,
            'comment_cnt'      => 0,
            'share_cnt'        => 0,
            'live_duration'    => 0,
            'item_show_cnt'    => 0,
            'item_click_cnt'   => 0,
            'sale_product_cnt' => 0,
            'sale_amount'      => 0,
            'item_click_rate'  => 0,
        ];

        $trend   = getDayArr($stDate, $enDate, $formatData);
        $summary = [
            'tal_real_amount'      => 0,
            'tal_play_cnt'         => 0,
            'tal_play_uv'          => 0,
            'tal_like_cnt'         => 0,
            'tal_comment_cnt'      => 0,
            'tal_share_cnt'        => 0,
            'tal_live_duration'    => 0,
            'tal_item_show_cnt'    => 0,
            'tal_item_click_cnt'   => 0,
            'tal_sale_product_cnt' => 0,
            'tal_sale_amount'      => 0,
            'tal_cpm'              => 0,
            'tal_item_click_rate'  => 0,
            'tal_cpa'              => 0
        ];
        $list = [];

        if (!empty($adverIds)) {
            $orderList = JxStarLiveOrderList::query()
                ->selectRaw("DATE_FORMAT(live_start_time, '%Y-%m-%d') AS day")
                ->selectRaw("SUM(real_amount) AS real_amount")
                ->selectRaw("SUM(play_cnt) AS play_cnt")
                ->selectRaw("SUM(play_uv) AS play_uv")
                ->selectRaw("SUM(like_cnt) AS like_cnt")
                ->selectRaw("SUM(comment_cnt) AS comment_cnt")
                ->selectRaw("SUM(share_cnt) AS share_cnt")
                ->selectRaw("SUM(live_duration) AS live_duration")
                ->selectRaw("SUM(item_show_cnt) AS item_show_cnt")
                ->selectRaw("SUM(item_click_cnt) AS item_click_cnt")
                ->selectRaw("SUM(sale_product_cnt) AS sale_product_cnt")
                ->selectRaw("SUM(sale_amount) AS sale_amount")
                ->whereIn('advertiser_id', $adverIds)
                ->whereBetween('live_start_time', [$stDate.' 00:00:00', $enDate.' 23:59:59'])
                ->groupBy('day')
                ->orderByDesc('day')
                ->get();
            if ($orderList->isNotEmpty()) {
                $orderListMap = $orderList->keyBy('day')->toArray();

                foreach ($trend as &$item) {
                    $dataVal = $orderListMap[$item['day']] ?? [];
                    if (empty($dataVal)) continue;

                    # 处理汇总
                    $summary['tal_real_amount']      += $dataVal['real_amount'];
                    $summary['tal_play_cnt']         += $dataVal['play_cnt'];
                    $summary['tal_play_uv']          += $dataVal['play_uv'];
                    $summary['tal_like_cnt']         += $dataVal['like_cnt'];
                    $summary['tal_comment_cnt']      += $dataVal['comment_cnt'];
                    $summary['tal_share_cnt']        += $dataVal['share_cnt'];
                    $summary['tal_live_duration']    += $dataVal['live_duration'];
                    $summary['tal_item_show_cnt']    += $dataVal['item_show_cnt'];
                    $summary['tal_item_click_cnt']   += $dataVal['item_click_cnt'];
                    $summary['tal_sale_product_cnt'] += $dataVal['sale_product_cnt'];
                    $summary['tal_sale_amount']      += $dataVal['sale_amount'];

                    # 处理列表
                    $list[] = [
                        'day'                 => $dataVal['day'],
                        'play_cnt'            => $dataVal['play_cnt'],
                        'play_uv'             => $dataVal['play_uv'],
                        'like_cnt'            => $dataVal['like_cnt'],
                        'comment_cnt'         => $dataVal['comment_cnt'],
                        'share_cnt'           => $dataVal['share_cnt'],
                        'live_duration'       => $dataVal['live_duration'],
                        'item_show_cnt'       => $dataVal['item_show_cnt'],
                        'item_click_cnt'      => $dataVal['item_click_cnt'],
                        'sale_product_cnt'    => $dataVal['sale_product_cnt'],
                        'sale_amount'         => $dataVal['sale_amount'],
                        'real_amount'         => round($dataVal['real_amount'] / 1000, 4),
                        'cpm'                 => $dataVal['play_cnt'] > 0
                            ? round($dataVal['real_amount'] / $dataVal['play_cnt'], 4) : 0,
                        'item_click_rate'     => $dataVal['item_show_cnt'] > 0
                            ? round($dataVal['item_click_cnt'] / $dataVal['item_show_cnt'] * 100, 4) : 0,
                        'cpa'                 => $dataVal['item_click_cnt'] > 0
                            ? round(($dataVal['real_amount'] / $dataVal['item_click_cnt']) / 1000, 4) : 0,
                    ];

                    # 处理曲线
                    $dataVal['real_amount']     = round($dataVal['real_amount'] / 1000, 4);
                    $dataVal['sale_amount']     = round($dataVal['sale_amount'] / 1000, 4);
                    $dataVal['item_click_rate'] = $dataVal['item_show_cnt'] > 0
                        ? round($dataVal['item_click_cnt'] / $dataVal['item_show_cnt'] * 100, 4) : 0;
                    $item = $dataVal;
                }

                $summary['tal_cpm']             = $summary['tal_play_cnt'] > 0
                    ? round($summary['tal_real_amount'] / $summary['tal_play_cnt'], 4) : 0;
                $summary['tal_item_click_rate'] = $summary['tal_item_show_cnt'] > 0
                    ? round($summary['tal_item_click_cnt'] / $summary['tal_item_show_cnt'] * 100, 4) : 0;
                $summary['tal_cpa']             = $summary['tal_play_cnt'] > 0
                    ? round(($summary['tal_real_amount'] / $summary['tal_item_click_cnt']) / 1000, 4) : 0;
                $summary['tal_real_amount']     = round($summary['tal_real_amount'] / 1000, 4);
            }
        }

        self::sortData($list);
        return [
            'trend'   => $trend,
            'summary' => $summary,
            'list'    => $list
        ];
    }

    protected static function getProQtaskVideoData($adverIds, $stDate, $enDate)
    {
        $formatData = [
            'amount'              => 0,
            'view'                => 0,
            'play'                => 0,
            'action'              => 0,
            'admire'              => 0,
            'comment'             => 0,
            'click'               => 0,
            'play_3s'             => 0,
            'play_5s'             => 0,
            'play_end'            => 0,
            'item_impression_cnt' => 0,
            'item_click_cnt'      => 0,
            'click_rate'          => 0,
            'play_3s_rate'        => 0,
            'play_5s_rate'        => 0,
            'play_end_rate'       => 0,
            'item_click_rate'     => 0,
        ];

        $trend   = getDayArr($stDate, $enDate, $formatData);
        $summary = [
            'tal_amount'              => 0,
            'tal_view'                => 0,
            'tal_play'                => 0,
            'tal_action'              => 0,
            'tal_admire'              => 0,
            'tal_comment'             => 0,
            'tal_click'               => 0,
            'tal_play_3s'             => 0,
            'tal_play_5s'             => 0,
            'tal_play_end'            => 0,
            'tal_item_impression_cnt' => 0,
            'tal_item_click_cnt'      => 0,
            'tal_ctr'                 => 0,
            'tal_cpm'                 => 0,
            'tal_cpc'                 => 0,
            'tal_item_click_rate'     => 0,
            'tal_cpa'                 => 0,
            'tal_play_3s_rate'        => 0,
            'tal_play_5s_rate'        => 0,
            'tal_play_end_rate'       => 0,

        ];
        $list = [];

        if (!empty($adverIds)) {
            $orderList = JxQtaskVideoOrderList::query()
                ->selectRaw("DATE_FORMAT(star_release_time, '%Y-%m-%d') AS day")
                ->selectRaw("SUM(amount) AS amount")
                ->selectRaw("SUM(view) AS view")
                ->selectRaw("SUM(play) AS play")
                ->selectRaw("SUM(action) AS action")
                ->selectRaw("SUM(admire) AS admire")
                ->selectRaw("SUM(comment) AS comment")
                ->selectRaw("SUM(click) AS click")
                ->selectRaw("SUM(play_3s) AS play_3s")
                ->selectRaw("SUM(play_5s) AS play_5s")
                ->selectRaw("SUM(play_end) AS play_end")
                ->selectRaw("SUM(item_impression_cnt) AS item_impression_cnt")
                ->selectRaw("SUM(item_click_cnt) AS item_click_cnt")
                ->whereIn('advertiser_id', $adverIds)
                ->whereBetween('star_release_time', [$stDate.' 00:00:00', $enDate.' 23:59:59'])
                ->groupBy('day')
                ->orderByDesc('day')
                ->get();

            if ($orderList->isNotEmpty()) {
                $orderListMap = $orderList->keyBy('day')->toArray();

                foreach ($trend as &$item) {
                    $dataVal = $orderListMap[$item['day']] ?? [];
                    if (empty($dataVal)) continue;

                    # 处理汇总
                    $summary['tal_amount']              += $dataVal['amount'];
                    $summary['tal_view']                += $dataVal['view'];
                    $summary['tal_play']                += $dataVal['play'];
                    $summary['tal_action']              += $dataVal['action'];
                    $summary['tal_admire']              += $dataVal['admire'];
                    $summary['tal_comment']             += $dataVal['comment'];
                    $summary['tal_click']               += $dataVal['click'];
                    $summary['tal_play_3s']             += $dataVal['play_3s'];
                    $summary['tal_play_5s']             += $dataVal['play_5s'];
                    $summary['tal_play_end']            += $dataVal['play_end'];
                    $summary['tal_item_impression_cnt'] += $dataVal['item_impression_cnt'];
                    $summary['tal_item_click_cnt']      += $dataVal['item_click_cnt'];

                    # 处理列表
                    $list[] = [
                        'day'                 => $dataVal['day'],
                        'view'                => $dataVal['view'],
                        'play'                => $dataVal['play'],
                        'action'              => $dataVal['action'],
                        'admire'              => $dataVal['admire'],
                        'comment'             => $dataVal['comment'],
                        'click'               => $dataVal['click'],
                        'play_3s'             => $dataVal['play_3s'],
                        'play_5s'             => $dataVal['play_5s'],
                        'play_end'            => $dataVal['play_end'],
                        'item_impression_cnt' => $dataVal['item_impression_cnt'],
                        'item_click_cnt'      => $dataVal['item_click_cnt'],
                        'amount'              => round($dataVal['amount'] / 1000, 4),
                        'ctr'                 => $dataVal['view'] > 0
                            ? round($dataVal['click'] / $dataVal['view'] * 100, 4) : 0,
                        'cpm'                 => $dataVal['play'] > 0
                            ? round($dataVal['amount'] / $dataVal['play'], 4) : 0,
                        'cpc'                 => $dataVal['click'] > 0
                            ? round(($dataVal['amount'] / $dataVal['click']) / 1000, 4) : 0,
                        'item_click_rate'     => $dataVal['item_impression_cnt'] > 0
                            ? round($dataVal['item_click_cnt'] / $dataVal['item_impression_cnt'] * 100, 4) : 0,
                        'cpa'                 => $dataVal['item_click_cnt'] > 0
                            ? round(($dataVal['amount'] / $dataVal['item_click_cnt']) / 1000, 4) : 0,
                        'play_3s_rate'        => $dataVal['play'] > 0
                            ? round($dataVal['play_3s'] / $dataVal['play'] * 100, 4) : 0,
                        'play_5s_rate'        => $dataVal['play'] > 0
                            ? round($dataVal['play_5s'] / $dataVal['play'] * 100, 4) : 0,
                        'play_end_rate'       => $dataVal['play'] > 0
                            ? round($dataVal['play_end'] / $dataVal['play'] * 100, 4) : 0,
                    ];

                    # 处理曲线
                    $dataVal['amount']              = round($dataVal['amount'] / 1000, 4);
                    $dataVal['click_rate']          = $dataVal['view'] > 0
                        ? round($dataVal['click'] / $dataVal['view'] * 100, 4) : 0;
                    $dataVal['play_3s_rate']        = $dataVal['play'] > 0
                        ? round($dataVal['play_3s'] / $dataVal['play'] * 100, 4) : 0;
                    $dataVal['play_5s_rate']        = $dataVal['play'] > 0
                        ? round($dataVal['play_5s'] / $dataVal['play'] * 100, 4) : 0;
                    $dataVal['play_end_rate']       = $dataVal['play'] > 0
                        ? round($dataVal['play_end'] / $dataVal['play'] * 100, 4) : 0;
                    $dataVal['item_click_rate']     = $dataVal['item_impression_cnt'] > 0
                        ? round($dataVal['item_click_cnt'] / $dataVal['item_impression_cnt'] * 100, 4) : 0;
                    $item = $dataVal;
                }

                $summary['tal_ctr']             = $summary['tal_view'] > 0
                    ? round($summary['tal_click'] / $summary['tal_view'] * 100, 4) : 0;
                $summary['tal_cpm']             = $summary['tal_play'] > 0
                    ? round($summary['tal_amount'] / $summary['tal_play'], 4) : 0;
                $summary['tal_cpc']             = $summary['tal_click'] > 0
                    ? round(($summary['tal_amount'] / $summary['tal_click']) / 1000, 4) : 0;
                $summary['tal_item_click_rate'] = $summary['tal_item_impression_cnt'] > 0
                    ? round($summary['tal_item_click_cnt'] / $summary['tal_item_impression_cnt'] * 100, 4) : 0;
                $summary['tal_cpa']             = $summary['tal_item_click_cnt'] > 0
                    ? round(($summary['tal_amount'] / $summary['tal_item_click_cnt']) / 1000, 4) : 0;
                $summary['tal_play_3s_rate']        = $summary['tal_play'] > 0
                    ? round($summary['tal_play_3s'] / $summary['tal_play'] * 100, 4) : 0;
                $summary['tal_play_5s_rate']        = $summary['tal_play'] > 0
                    ? round($summary['tal_play_5s'] / $summary['tal_play'] * 100, 4) : 0;
                $summary['tal_play_end_rate']       = $summary['tal_play'] > 0
                    ? round($summary['tal_play_end'] / $summary['tal_play'] * 100, 4) : 0;
                $summary['tal_amount']          = round($summary['tal_amount'] / 1000, 4);
            }
        }

        self::sortData($list);
        return [
            'trend'   => $trend,
            'summary' => $summary,
            'list'    => $list
        ];
    }

    protected static function getProQtaskLiveData($adverIds, $stDate, $enDate)
    {
        $formatData = [
            'amount'           => 0,
            'play_cnt'         => 0,
            'play_uv'          => 0,
            'like_cnt'         => 0,
            'comment_cnt'      => 0,
            'share_cnt'        => 0,
            'live_duration'    => 0,
            'item_show_cnt'    => 0,
            'item_click_cnt'   => 0,
            'item_click_rate'  => 0,
        ];

        $trend   = getDayArr($stDate, $enDate, $formatData);
        $summary = [
            'tal_amount'          => 0,
            'tal_play_cnt'        => 0,
            'tal_play_uv'         => 0,
            'tal_like_cnt'        => 0,
            'tal_comment_cnt'     => 0,
            'tal_share_cnt'       => 0,
            'tal_live_duration'   => 0,
            'tal_item_show_cnt'   => 0,
            'tal_item_click_cnt'  => 0,
            'tal_cpm'             => 0,
            'tal_item_click_rate' => 0,
            'tal_cpa'             => 0
        ];
        $list = [];

        if (!empty($adverIds)) {
            $orderList = JxQtaskLiveOrderList::query()
                ->selectRaw("DATE_FORMAT(star_release_time, '%Y-%m-%d') AS day")
                ->selectRaw("SUM(amount) AS amount")
                ->selectRaw("SUM(play_cnt) AS play_cnt")
                ->selectRaw("SUM(play_uv) AS play_uv")
                ->selectRaw("SUM(like_cnt) AS like_cnt")
                ->selectRaw("SUM(comment_cnt) AS comment_cnt")
                ->selectRaw("SUM(share_cnt) AS share_cnt")
                ->selectRaw("SUM(live_duration) AS live_duration")
                ->selectRaw("SUM(item_show_cnt) AS item_show_cnt")
                ->selectRaw("SUM(item_click_cnt) AS item_click_cnt")
                ->whereIn('advertiser_id', $adverIds)
                ->whereBetween('star_release_time', [$stDate.' 00:00:00', $enDate.' 23:59:59'])
                ->groupBy('day')
                ->orderByDesc('day')
                ->get();

            if ($orderList->isNotEmpty()) {
                $orderListMap = $orderList->keyBy('day')->toArray();

                foreach ($trend as &$item) {
                    $dataVal = $orderListMap[$item['day']] ?? [];
                    if (empty($dataVal)) continue;

                    # 处理汇总
                    $summary['tal_amount']         += $dataVal['amount'];
                    $summary['tal_play_cnt']       += $dataVal['play_cnt'];
                    $summary['tal_play_uv']        += $dataVal['play_uv'];
                    $summary['tal_like_cnt']       += $dataVal['like_cnt'];
                    $summary['tal_comment_cnt']    += $dataVal['comment_cnt'];
                    $summary['tal_share_cnt']      += $dataVal['share_cnt'];
                    $summary['tal_live_duration']  += $dataVal['live_duration'];
                    $summary['tal_item_show_cnt']  += $dataVal['item_show_cnt'];
                    $summary['tal_item_click_cnt'] += $dataVal['item_click_cnt'];

                    # 处理列表
                    $list[] = [
                        'day'                 => $dataVal['day'],
                        'play_cnt'            => $dataVal['play_cnt'],
                        'play_uv'             => $dataVal['play_uv'],
                        'like_cnt'            => $dataVal['like_cnt'],
                        'comment_cnt'         => $dataVal['comment_cnt'],
                        'share_cnt'           => $dataVal['share_cnt'],
                        'live_duration'       => $dataVal['live_duration'],
                        'item_show_cnt'       => $dataVal['item_show_cnt'],
                        'item_click_cnt'      => $dataVal['item_click_cnt'],
                        'amount'              => round($dataVal['amount'] / 1000, 4),
                        'cpm'                 => $dataVal['play_cnt'] > 0
                            ? round($dataVal['amount'] / $dataVal['play_cnt'], 4) : 0,
                        'item_click_rate'     => $dataVal['item_show_cnt'] > 0
                            ? round($dataVal['item_click_cnt'] / $dataVal['item_show_cnt'] * 100, 4) : 0,
                        'cpa'                 => $dataVal['item_click_cnt'] > 0
                            ? round(($dataVal['amount'] / $dataVal['item_click_cnt']) / 1000, 4) : 0,
                    ];

                    # 处理曲线
                    $dataVal['amount']          = round($dataVal['amount'] / 1000, 4);
                    $dataVal['item_click_rate'] = $dataVal['item_show_cnt'] > 0
                        ? round($dataVal['item_click_cnt'] / $dataVal['item_show_cnt'], 4) : 0;
                    $item = $dataVal;
                }

                $summary['tal_cpm']             = $summary['tal_play_cnt'] > 0
                    ? round($summary['tal_amount'] / $summary['tal_play_cnt'], 4) : 0;
                $summary['tal_item_click_rate'] = $summary['tal_item_show_cnt'] > 0
                    ? round($summary['tal_item_click_cnt'] / $summary['tal_item_show_cnt'] * 100, 4) : 0;
                $summary['tal_cpa']             = $summary['tal_item_click_cnt'] > 0
                    ? round(($summary['tal_amount'] / $summary['tal_item_click_cnt']) / 1000, 4) : 0;
                $summary['tal_amount']          = round($summary['tal_amount'] / 1000, 4);
            }
        }

        self::sortData($list);
        return [
            'trend'   => $trend,
            'summary' => $summary,
            'list'    => $list
        ];
    }

    protected static function getProFlowStarVideoData($adverIds, $stDate, $enDate)
    {
        $formatData = [
            'consume_amount'        => 0,
            'view'                  => 0,
            'play'                  => 0,
            'action'                => 0,
            'conversion'            => 0,
            'admire'                => 0,
            'comment'               => 0,
            'played3s_cnt'          => 0,
            'cash_amount'           => 0,
            'client_amount'         => 0,
            'agency_amount'         => 0,
            'credit_consume_amount' => 0,
            'play_3s_rate'          => 0,
            'action_rate'           => 0,
        ];

        $trend   = getDayArr($stDate, $enDate, $formatData);
        $summary = [
            'tal_consume_amount'        => 0,
            'tal_view'                  => 0,
            'tal_play'                  => 0,
            'tal_action'                => 0,
            'tal_conversion'            => 0,
            'tal_admire'                => 0,
            'tal_comment'               => 0,
            'tal_played3s_cnt'          => 0,
            'tal_cash_amount'           => 0,
            'tal_client_amount'         => 0,
            'tal_agency_amount'         => 0,
            'tal_credit_consume_amount' => 0,
            'tal_cpm'                   => 0,
            'tal_action_rate'           => 0,
            'tal_cpa'                   => 0,
            'tal_play_3s_rate'          => 0
        ];
        $list = [];

        if (!empty($adverIds)) {
            $orderList = JxStarVideoFlowOrderList::query()
                ->selectRaw("DATE_FORMAT(promotion_begin_time, '%Y-%m-%d') AS day")
                ->selectRaw("SUM(consume_amount) AS consume_amount")
                ->selectRaw("SUM(view) AS view")
                ->selectRaw("SUM(play) AS play")
                ->selectRaw("SUM(action) AS action")
                ->selectRaw("SUM(conversion) AS conversion")
                ->selectRaw("SUM(admire) AS admire")
                ->selectRaw("SUM(comment) AS comment")
                ->selectRaw("SUM(played3s_cnt) AS played3s_cnt")
                ->selectRaw("SUM(cash_amount) AS cash_amount")
                ->selectRaw("SUM(client_amount) AS client_amount")
                ->selectRaw("SUM(agency_amount) AS agency_amount")
                ->selectRaw("SUM(credit_consume_amount) AS credit_consume_amount")
                ->whereIn('advertiser_id', $adverIds)
                ->whereBetween('promotion_begin_time', [$stDate.' 00:00:00', $enDate.' 23:59:59'])
                ->groupBy('day')
                ->orderByDesc('day')
                ->get();

            if ($orderList->isNotEmpty()) {
                $orderListMap = $orderList->keyBy('day')->toArray();

                foreach ($trend as &$item) {
                    $dataVal = $orderListMap[$item['day']] ?? [];
                    if (empty($dataVal)) continue;

                    # 处理汇总
                    $summary['tal_consume_amount']        += $dataVal['consume_amount'];
                    $summary['tal_view']                  += $dataVal['view'];
                    $summary['tal_play']                  += $dataVal['play'];
                    $summary['tal_action']                += $dataVal['action'];
                    $summary['tal_conversion']            += $dataVal['conversion'];
                    $summary['tal_admire']                += $dataVal['admire'];
                    $summary['tal_comment']               += $dataVal['comment'];
                    $summary['tal_played3s_cnt']          += $dataVal['played3s_cnt'];
                    $summary['tal_cash_amount']           += $dataVal['cash_amount'];
                    $summary['tal_client_amount']         += $dataVal['client_amount'];
                    $summary['tal_agency_amount']         += $dataVal['agency_amount'];
                    $summary['tal_credit_consume_amount'] += $dataVal['credit_consume_amount'];

                    # 处理列表
                    $list[] = [
                        'day'                   => $dataVal['day'],
                        'view'                  => $dataVal['view'],
                        'play'                  => $dataVal['play'],
                        'action'                => $dataVal['action'],
                        'conversion'            => $dataVal['conversion'],
                        'admire'                => $dataVal['admire'],
                        'comment'               => $dataVal['comment'],
                        'played3s_cnt'          => $dataVal['played3s_cnt'],
                        'cash_amount'           => round($dataVal['cash_amount'] / 1000, 4),
                        'client_amount'         => round($dataVal['client_amount'] / 1000, 4),
                        'agency_amount'         => round($dataVal['agency_amount'] / 1000, 4),
                        'credit_consume_amount' => round($dataVal['credit_consume_amount'] / 1000, 4),
                        'consume_amount'        => round($dataVal['consume_amount'] / 1000, 4),
                        'cpm'                   => $dataVal['play'] > 0
                            ? round($dataVal['consume_amount'] / $dataVal['play'], 4) : 0,
                        'action_rate'           => $dataVal['play'] > 0
                            ? round($dataVal['action'] / $dataVal['play'] * 100, 4) : 0,
                        'cpa'                   => $dataVal['conversion'] > 0
                            ? round(($dataVal['consume_amount'] / $dataVal['conversion']) / 1000, 4) : 0,
                        'play_3s_rate'          => $dataVal['play'] > 0
                            ? round($dataVal['played3s_cnt'] / $dataVal['play'] * 100, 4) : 0,
                    ];


                    # 处理曲线
                    $dataVal['consume_amount']        = round($dataVal['consume_amount'] / 1000, 4);
                    $dataVal['cash_amount']           = round($dataVal['cash_amount'] / 1000, 4);
                    $dataVal['client_amount']         = round($dataVal['client_amount'] / 1000, 4);
                    $dataVal['agency_amount']         = round($dataVal['agency_amount'] / 1000, 4);
                    $dataVal['credit_consume_amount'] = round($dataVal['credit_consume_amount'] / 1000, 4);
                    $dataVal['play_3s_rate']          = $dataVal['play'] > 0
                        ? round($dataVal['played3s_cnt'] / $dataVal['play'] * 100, 4) : 0;
                    $dataVal['action_rate']           = $dataVal['play'] > 0
                        ? round($dataVal['action'] / $dataVal['play'] * 100, 4) : 0;
                    $item = $dataVal;
                }

                $summary['tal_cpm']                   = $summary['tal_play'] > 0
                    ? round($summary['tal_consume_amount'] / $summary['tal_play'], 4) : 0;
                $summary['tal_action_rate']           = $summary['tal_play'] > 0
                    ? round($summary['tal_action'] / $summary['tal_play'] * 100, 4) : 0;
                $summary['tal_cpa']                   = $summary['tal_conversion'] > 0
                    ? round(($summary['tal_consume_amount'] / $summary['tal_conversion']) / 1000, 4) : 0;
                $summary['tal_consume_amount']        = round($summary['tal_consume_amount'] / 1000, 4);
                $summary['tal_cash_amount']           = round($summary['tal_cash_amount'] / 1000, 4);
                $summary['tal_client_amount']         = round($summary['tal_client_amount'] / 1000, 4);
                $summary['tal_agency_amount']         = round($summary['tal_agency_amount'] / 1000, 4);
                $summary['tal_credit_consume_amount'] = round($summary['tal_credit_consume_amount'] / 1000, 4);
                $summary['tal_play_3s_rate']          = $summary['tal_play'] > 0
                    ? round($summary['tal_played3s_cnt'] / $summary['tal_play'] * 100, 4) : 0;
            }
        }

        self::sortData($list);
        return [
            'trend'   => $trend,
            'summary' => $summary,
            'list'    => $list
        ];
    }

    protected static function getProFlowStarLiveData($adverIds, $stDate, $enDate)
    {
        $formatData = [
            'consume_amount'            => 0,
            'audience_num'              => 0,
            'played3s_num'              => 0,
            'fans_increase_num'         => 0,
            'item_impression_num'       => 0,
            'interactive_num'           => 0,
            'conversion_impression_num' => 0,
            'conversion_action_num'     => 0,
            'cash_amount'               => 0,
            'client_amount'             => 0,
            'agency_amount'             => 0,
            'credit_consume_amount'     => 0,
            'conversion_action_cost'    => 0
        ];

        $trend   = getDayArr($stDate, $enDate, $formatData);
        $summary = [
            'tal_consume_amount'            => 0,
            'tal_audience_num'              => 0,
            'tal_played3s_num'              => 0,
            'tal_fans_increase_num'         => 0,
            'tal_item_impression_num'       => 0,
            'tal_interactive_num'           => 0,
            'tal_conversion_impression_num' => 0,
            'tal_conversion_action_num'     => 0,
            'tal_cash_amount'               => 0,
            'tal_client_amount'             => 0,
            'tal_agency_amount'             => 0,
            'tal_credit_consume_amount'     => 0,
            'tal_conversion_action_rate'    => 0,
            'tal_cpa'                       => 0,
            'tal_conversion_action_cost'    => 0
        ];
        $list = [];

        if (!empty($adverIds)) {
            $orderList = JxStarLiveFlowOrderList::query()
                ->selectRaw("DATE_FORMAT(promotion_begin_time, '%Y-%m-%d') AS day")
                ->selectRaw("SUM(consume_amount) AS consume_amount")
                ->selectRaw("SUM(audience_num) AS audience_num")
                ->selectRaw("SUM(played3s_num) AS played3s_num")
                ->selectRaw("SUM(fans_increase_num) AS fans_increase_num")
                ->selectRaw("SUM(item_impression_num) AS item_impression_num")
                ->selectRaw("SUM(interactive_num) AS interactive_num")
                ->selectRaw("SUM(conversion_impression_num) AS conversion_impression_num")
                ->selectRaw("SUM(conversion_action_num) AS conversion_action_num")
                ->selectRaw("SUM(cash_amount) AS cash_amount")
                ->selectRaw("SUM(client_amount) AS client_amount")
                ->selectRaw("SUM(agency_amount) AS agency_amount")
                ->selectRaw("SUM(credit_consume_amount) AS credit_consume_amount")
                ->whereIn('advertiser_id', $adverIds)
                ->whereBetween('promotion_begin_time', [$stDate.' 00:00:00', $enDate.' 23:59:59'])
                ->groupBy('day')
                ->orderByDesc('day')
                ->get();

            if ($orderList->isNotEmpty()) {
                $orderListMap = $orderList->keyBy('day')->toArray();

                foreach ($trend as &$item) {
                    $dataVal = $orderListMap[$item['day']] ?? [];
                    if (empty($dataVal)) continue;

                    # 处理汇总
                    $summary['tal_consume_amount']            += $dataVal['consume_amount'];
                    $summary['tal_audience_num']              += $dataVal['audience_num'];
                    $summary['tal_played3s_num']              += $dataVal['played3s_num'];
                    $summary['tal_fans_increase_num']         += $dataVal['fans_increase_num'];
                    $summary['tal_item_impression_num']       += $dataVal['item_impression_num'];
                    $summary['tal_interactive_num']           += $dataVal['interactive_num'];
                    $summary['tal_conversion_impression_num'] += $dataVal['conversion_impression_num'];
                    $summary['tal_conversion_action_num']     += $dataVal['conversion_action_num'];
                    $summary['tal_cash_amount']               += $dataVal['cash_amount'];
                    $summary['tal_client_amount']             += $dataVal['client_amount'];
                    $summary['tal_agency_amount']             += $dataVal['agency_amount'];
                    $summary['tal_credit_consume_amount']     += $dataVal['credit_consume_amount'];

                    # 处理列表
                    $list[] = [
                        'day'                       => $dataVal['day'],
                        'audience_num'              => $dataVal['audience_num'],
                        'played3s_num'              => $dataVal['played3s_num'],
                        'fans_increase_num'         => $dataVal['fans_increase_num'],
                        'item_impression_num'       => $dataVal['item_impression_num'],
                        'interactive_num'           => $dataVal['interactive_num'],
                        'conversion_impression_num' => $dataVal['conversion_impression_num'],
                        'conversion_action_num'     => $dataVal['conversion_action_num'],
                        'cash_amount'               => round($dataVal['cash_amount'] / 1000, 4),
                        'client_amount'             => round($dataVal['client_amount'] / 1000, 4),
                        'agency_amount'             => round($dataVal['agency_amount'] / 1000, 4),
                        'credit_consume_amount'     => round($dataVal['credit_consume_amount'] / 1000, 4),
                        'consume_amount'            => round($dataVal['consume_amount'] / 1000, 4),
                        'conversion_action_rate'    => $dataVal['conversion_impression_num'] > 0
                            ? round($dataVal['conversion_action_num'] / $dataVal['conversion_impression_num'] * 100, 4) : 0,
                        'cpa'                       => $dataVal['consume_amount'] > 0
                            ? round(($dataVal['consume_amount'] / $dataVal['conversion_action_num']) / 1000, 4) : 0,
                        'conversion_action_cost'    => $dataVal['conversion_action_num'] > 0
                            ? round(($dataVal['consume_amount'] / $dataVal['conversion_action_num']) / 1000, 4) : 0
                    ];

                    # 处理曲线
                    $dataVal['consume_amount']         = round($dataVal['consume_amount'] / 1000, 4);
                    $dataVal['cash_amount']            = round($dataVal['cash_amount'] / 1000, 4);
                    $dataVal['client_amount']          = round($dataVal['client_amount'] / 1000, 4);
                    $dataVal['agency_amount']          = round($dataVal['agency_amount'] / 1000, 4);
                    $dataVal['credit_consume_amount']  = round($dataVal['credit_consume_amount'] / 1000, 4);
                    $dataVal['conversion_action_cost'] = $dataVal['conversion_action_num'] > 0
                        ? round(($dataVal['consume_amount'] / $dataVal['conversion_action_num']) / 1000, 4) : 0;
                    $item = $dataVal;
                }

                $summary['tal_conversion_action_rate'] = $summary['tal_conversion_impression_num'] > 0
                    ? round($summary['tal_conversion_action_num'] / $summary['tal_conversion_impression_num'] * 100, 4) : 0;
                $summary['tal_cpa']                    = $summary['tal_conversion_action_num'] > 0
                    ? round(($summary['tal_consume_amount'] / $summary['tal_conversion_action_num']) / 1000, 4) : 0;
                $summary['tal_consume_amount']         = round($summary['tal_consume_amount'] / 1000, 4);
                $summary['tal_cash_amount']            = round($summary['tal_cash_amount'] / 1000, 4);
                $summary['tal_client_amount']          = round($summary['tal_client_amount'] / 1000, 4);
                $summary['tal_agency_amount']          = round($summary['tal_agency_amount'] / 1000, 4);
                $summary['tal_credit_consume_amount']  = round($summary['tal_credit_consume_amount'] / 1000, 4);
                $summary['tal_conversion_action_cost'] = $summary['tal_conversion_action_num'] > 0
                    ? round(($summary['tal_consume_amount'] / $summary['tal_conversion_action_num']) / 1000, 4) : 0;
            }
        }

        self::sortData($list);
        return [
            'trend'   => $trend,
            'summary' => $summary,
            'list'    => $list
        ];
    }

    protected static function getProFlowQtaskVideoData($adverIds, $stDate, $enDate)
    {
        $formatData = [
            'consume_amount'        => 0,
            'view'                  => 0,
            'play'                  => 0,
            'action'                => 0,
            'conversion'            => 0,
            'comment'               => 0,
            'admire'                => 0,
            'played3s_cnt'          => 0,
            'cash_amount'           => 0,
            'client_amount'         => 0,
            'agency_amount'         => 0,
            'credit_consume_amount' => 0,
            'play_3s_rate'          => 0,
            'action_rate'           => 0,
        ];

        $trend   = getDayArr($stDate, $enDate, $formatData);
        $summary = [
            'tal_consume_amount'        => 0,
            'tal_view'                  => 0,
            'tal_play'                  => 0,
            'tal_action'                => 0,
            'tal_conversion'            => 0,
            'tal_admire'                => 0,
            'tal_comment'               => 0,
            'tal_played3s_cnt'          => 0,
            'tal_cash_amount'           => 0,
            'tal_client_amount'         => 0,
            'tal_agency_amount'         => 0,
            'tal_credit_consume_amount' => 0,
            'tal_cpm'                   => 0,
            'tal_action_rate'           => 0,
            'tal_cpa'                   => 0,
            'tal_play_3s_rate'          => 0
        ];
        $list = [];

        if (!empty($adverIds)) {
            $orderList = JxQtaskVideoFlowOrderList::query()
                ->selectRaw("DATE_FORMAT(promotion_begin_time, '%Y-%m-%d') AS day")
                ->selectRaw("SUM(consume_amount) AS consume_amount")
                ->selectRaw("SUM(view) AS view")
                ->selectRaw("SUM(play) AS play")
                ->selectRaw("SUM(action) AS action")
                ->selectRaw("SUM(conversion) AS conversion")
                ->selectRaw("SUM(admire) AS admire")
                ->selectRaw("SUM(comment) AS comment")
                ->selectRaw("SUM(played3s_cnt) AS played3s_cnt")
                ->selectRaw("SUM(cash_amount) AS cash_amount")
                ->selectRaw("SUM(client_amount) AS client_amount")
                ->selectRaw("SUM(agency_amount) AS agency_amount")
                ->selectRaw("SUM(credit_consume_amount) AS credit_consume_amount")
                ->whereIn('advertiser_id', $adverIds)
                ->whereBetween('promotion_begin_time', [$stDate.' 00:00:00', $enDate.' 23:59:59'])
                ->groupBy('day')
                ->orderByDesc('day')
                ->get();

            if ($orderList->isNotEmpty()) {
                $orderListMap = $orderList->keyBy('day')->toArray();

                foreach ($trend as &$item) {
                    $dataVal = $orderListMap[$item['day']] ?? [];
                    if (empty($dataVal)) continue;

                    # 处理汇总
                    $summary['tal_consume_amount']        += $dataVal['consume_amount'];
                    $summary['tal_view']                  += $dataVal['view'];
                    $summary['tal_play']                  += $dataVal['play'];
                    $summary['tal_action']                += $dataVal['action'];
                    $summary['tal_conversion']            += $dataVal['conversion'];
                    $summary['tal_admire']                += $dataVal['admire'];
                    $summary['tal_comment']               += $dataVal['comment'];
                    $summary['tal_played3s_cnt']          += $dataVal['played3s_cnt'];
                    $summary['tal_cash_amount']           += $dataVal['cash_amount'];
                    $summary['tal_client_amount']         += $dataVal['client_amount'];
                    $summary['tal_agency_amount']         += $dataVal['agency_amount'];
                    $summary['tal_credit_consume_amount'] += $dataVal['credit_consume_amount'];

                    # 处理列表
                    $list[] = [
                        'day'                   => $dataVal['day'],
                        'view'                  => $dataVal['view'],
                        'play'                  => $dataVal['play'],
                        'action'                => $dataVal['action'],
                        'conversion'            => $dataVal['conversion'],
                        'admire'                => $dataVal['admire'],
                        'comment'               => $dataVal['comment'],
                        'played3s_cnt'          => $dataVal['played3s_cnt'],
                        'cash_amount'           => round($dataVal['cash_amount'] / 1000, 4),
                        'client_amount'         => round($dataVal['client_amount'] / 1000, 4),
                        'agency_amount'         => round($dataVal['agency_amount'] / 1000, 4),
                        'credit_consume_amount' => round($dataVal['credit_consume_amount'] / 1000, 4),
                        'consume_amount'        => round($dataVal['consume_amount'] / 1000, 4),
                        'cpm'                   => $dataVal['play'] > 0
                            ? round($dataVal['consume_amount'] / $dataVal['play'], 4) : 0,
                        'action_rate'           => $dataVal['play'] > 0
                            ? round($dataVal['action'] / $dataVal['play'] * 100, 4) : 0,
                        'cpa'                   => $dataVal['conversion'] > 0
                            ? round(($dataVal['consume_amount'] / $dataVal['conversion']) / 1000, 4) : 0,
                        'play_3s_rate'          => $dataVal['play'] > 0
                            ? round($dataVal['played3s_cnt'] / $dataVal['play'] * 100, 4) : 0,
                    ];


                    # 处理曲线
                    $dataVal['consume_amount']        = round($dataVal['consume_amount'] / 1000, 4);
                    $dataVal['cash_amount']           = round($dataVal['cash_amount'] / 1000, 4);
                    $dataVal['client_amount']         = round($dataVal['client_amount'] / 1000, 4);
                    $dataVal['agency_amount']         = round($dataVal['agency_amount'] / 1000, 4);
                    $dataVal['credit_consume_amount'] = round($dataVal['credit_consume_amount'] / 1000, 4);
                    $dataVal['play_3s_rate']          = $dataVal['play'] > 0
                        ? round($dataVal['played3s_cnt'] / $dataVal['play'] * 100, 4) : 0;
                    $dataVal['action_rate']           = $dataVal['play'] > 0
                        ? round($dataVal['action'] / $dataVal['play'] * 100, 4) : 0;
                    $item = $dataVal;
                }

                $summary['tal_cpm']                   = $summary['tal_play'] > 0
                    ? round($summary['tal_consume_amount'] / $summary['tal_play'], 4) : 0;
                $summary['tal_action_rate']           = $summary['tal_play'] > 0
                    ? round($summary['tal_action'] / $summary['tal_play'] * 100, 4) : 0;
                $summary['tal_cpa']                   = $summary['tal_conversion'] > 0
                    ? round(($summary['tal_consume_amount'] / $summary['tal_conversion']) / 1000, 4) : 0;
                $summary['tal_consume_amount']        = round($summary['tal_consume_amount'] / 1000, 4);
                $summary['tal_cash_amount']           = round($summary['tal_cash_amount'] / 1000, 4);
                $summary['tal_client_amount']         = round($summary['tal_client_amount'] / 1000, 4);
                $summary['tal_agency_amount']         = round($summary['tal_agency_amount'] / 1000, 4);
                $summary['tal_credit_consume_amount'] = round($summary['tal_credit_consume_amount'] / 1000, 4);
                $summary['tal_play_3s_rate']          = $summary['tal_play'] > 0
                    ? round($summary['tal_played3s_cnt'] / $summary['tal_play'] * 100, 4) : 0;

            }
        }

        self::sortData($list);
        return [
            'trend'   => $trend,
            'summary' => $summary,
            'list'    => $list
        ];
    }

    protected static function formatData(&$result)
    {
        # 格式化
        foreach ($result as &$item) {
            $item = round($item / 1000, 4);
        }
    }

    protected static function sortData(&$list)
    {
        # 时间倒序
        $dayList = array_column($list, 'day');
        array_multisort($dayList, SORT_DESC, $list);
    }
}
