<?php

namespace kwaiSDK;

use kwaiSDK\Api\JinNiu\Account;
use kwaiSDK\Api\JinNiu\Campaign;
use kwaiSDK\Api\JinNiu\Creative;
use kwaiSDK\Api\JinNiu\Report;
use kwaiSDK\Api\JinNiu\Unit;

class JinNiu
{
    protected $accessToken;
    protected $host;

    protected $options = [];

    function __construct($accessToken='', $host='https://ad.e.kuaishou.com'){
        $this->accessToken = $accessToken;
        $this->host        = $host;
    }

    /**
     * 初始化
     * */
    private function init(){
        return [
            'access_token' => $this->accessToken,
            'host'         => $this->host,
            'options'      => $this->options,
            'api_pre'      => '/rest/openapi/gw/esp/v1'
        ];
    }

    /**
     *  设置
     * */
    function setOptions(array $options=[]){
        $this->options = $options;
    }

    /**
     * 账户相关
     * */
    public function account(){
        return  new Account($this->init());
    }

    /**
     * 报表相关
     * */
    public function report(){
        return  new Report($this->init());
    }

    /**
     * 广告计划相关
     * */
    public function campaign(){
        return  new Campaign($this->init());
    }

    /**
     * 广告组相关
     * */
    public function Unit(){
        return  new Unit($this->init());
    }

    /**
     * 广告创意相关
     * */
    public function creative(){
        return  new Creative($this->init());
    }
}
